--- a/libg15.c
+++ b/libg15.c
@@ -152,7 +152,7 @@
                 if (!devh)
                 {
                     g15_log(stderr,G15_LOG_INFO, "Error, could not open the keyboard\n");
-                    g15_log(stderr,G15_LOG_INFO, "Perhaps you dont have enough permissions to access it\n");
+                    g15_log(stderr,G15_LOG_INFO, "Perhaps you don't have enough permissions to access it\n");
                     return 0;
                 }
 
@@ -434,7 +434,7 @@
         case -ETIMEDOUT:
             return G15_ERROR_READING_USB_DEVICE;  /* backward-compatibility */
             break;
-            case -ENOSPC: /* the we dont have enough bandwidth, apparently.. something has to give here.. */
+            case -ENOSPC: /* the we don't have enough bandwidth, apparently.. something has to give here.. */
                 g15_log(stderr,G15_LOG_INFO,"usb error: ENOSPC.. reducing speed\n");
                 enospc_slowdown = 1;
                 break;
